/*
Copyright (C) 2013 Bengt Martensson.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/.
*/

package org.harctoolbox.irscrutinizer.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.PrintStream;
import java.io.UnsupportedEncodingException;
import org.harctoolbox.IrpMaster.IrpMasterException;
import org.harctoolbox.IrpMaster.IrpUtils;
import org.harctoolbox.IrpMaster.LircExport;
import org.harctoolbox.girr.Command;
import org.harctoolbox.girr.Remote;
import org.harctoolbox.girr.RemoteSet;
import org.harctoolbox.irscrutinizer.Version;

/**
 * This class does something interesting and useful. Or not...
 */
public class LircExporter extends RemoteSetExporter implements IRemoteSetExporter {

    public LircExporter(File exportDir) {
        super(exportDir);
    }

    public LircExporter(String creatingUser, File exportDir) {
        super(creatingUser, exportDir);
    }

    @Override
    public String[][] getFileExtensions() {
        return new String[][] { new String[]{"txt", "Text files"}, new String[]{"lirc", "LIRC files"}};
    }

    // LIRC in general does not add extensions to its files, therefore we should not do it either.
    @Override
    public String getPreferredFileExtension() {
        return "lirc";
    }

    @Override
    public void export(RemoteSet remoteSet, String title, int count, File saveFile) throws FileNotFoundException, IrpMasterException {
        // LIRC often does not add extensions to its files, therefore we should not do it either.
        if (remoteSet.getAllCommands().isEmpty())
            throw new IllegalArgumentException("No commands in the remotes.");

        PrintStream out = null;
        try {
            out = new PrintStream(saveFile, IrpUtils.dumbCharsetName);
        } catch (UnsupportedEncodingException ex) {
            // cannot happen
            return;
        }

        for (Remote remote : remoteSet.getRemotes().values()) {
            Command randomCommand = remote.getCommands().values().iterator().next();
            LircExport lircExport = new LircExport(remote.getName(),
                    remote.getComment(),
                    creatingUser, remote.getManufacturer(), remote.getModel(),
                    Version.appName, Version.version, randomCommand.getFrequency());
            for (Command command : remote.getCommands().values()) {
                lircExport.addSignal(command.getName(), command.toIrSignal());
            }
            lircExport.write(out);
        }
        out.close();
    }

    @Override
    public String getFormatName() {
        return "LIRC";
    }
}
