/*
Copyright (C) 2013 Bengt Martensson.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or (at
your option) any later version.

This program is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/.
*/

package org.harctoolbox.irscrutinizer.importer;

import java.awt.Component;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.Reader;
import java.text.ParseException;
import javax.swing.JFileChooser;
import org.harctoolbox.guicomponents.SelectFile;
import org.harctoolbox.irscrutinizer.Version;

/**
 * This class extends the Importer with file load functions.
 */
public abstract class FileImporter extends Importer {

    protected FileImporter() {
        super();
    }

    public abstract void load(File file) throws IOException, ParseException;

    public boolean loadFileSelector(Component component, String title, String defaultDir) throws IOException, ParseException {
        File file = SelectFile.selectFile(component, title, defaultDir, false, false,
            canImportDirectories() ? JFileChooser.FILES_AND_DIRECTORIES : JFileChooser.FILES_ONLY, getFileExtensions());
        if (file == null)
            return false;
        load(file);
        return true;
    }

    protected void dumbLoad(Reader reader, String origin) throws FileNotFoundException, IOException, ParseException {
        FileOutputStream out = null;
        try {
            File file = File.createTempFile(Version.appName + origin, null);
            out = new FileOutputStream(file);
            while (true) {
                int c = reader.read(); // not written to be efficient...
                if (c == -1)
                    break;
                out.write(c);
            }
            load(file);
        } finally {
            if (out != null)
                out.close();
        }
    }

    public boolean canImportDirectories() {
        return false;
    }

    public abstract String[][] getFileExtensions();
}
